@@ -1,7 +1,7 @@
 #!/bin/bash
 
 chain_name=aembit-redirect-chain
-aembit_user_id=$(id --user aembit)
+aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
 agent_dns_port=8053
 
@@ -33,12 +33,12 @@ update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
 # 
 # See https://www.frozentux.net/iptables-tutorial/iptables-tutorial.html#STATEMACHINE
 # for more information on conntrack.
-iptables -t raw -A OUTPUT -p udp --dport 53 -m owner --uid-owner "${aembit_user_id}" -j NOTRACK
+iptables -t raw -A OUTPUT -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
 
 iptables  -t nat -N "${chain_name}"
 
 # Ignore (return to the main chain) all packets from our agent proxy
-iptables -t nat -A "${chain_name}" -m owner --uid-owner "${aembit_user_id}" -j RETURN
+iptables -t nat -A "${chain_name}" -m owner --gid-owner "${aembit_group_id}" -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -A "${chain_name}" -p tcp -o lo -j RETURN
